@@ -1,6 +1,5 @@
 package Ark::Context;
 use Mouse;
-use Mouse::Util::TypeConstraints;
 
 use Scalar::Util ();
 use Try::Tiny;
@@ -23,8 +22,7 @@ has response => (
     isa     => 'Ark::Response',
     lazy    => 1,
     default => sub {
-        my $self = shift;
-        Ark::Response->new( context => $self );
+        Ark::Response->new;
     },
 );
 
@@ -312,4 +310,3 @@ sub DEMOLISH {
 }
 
 __PACKAGE__->meta->make_immutable;
-
